@@ -6,17 +6,21 @@ class ProgramCmd:
                  end_date,
                  observation_status,
                  working_dir,
-                 payloads,
+                 archives,
                  waterfalls,
                  demoddata,
-                 payload_modules,
+                 archive_modules,
+                 archive_end_modules,
                  demoddata_modules,
+                 demoddata_end_modules,
                  waterfall_modules,
+                 waterfall_end_modules,
                  user,
                  transmitter_uuid,
                  transmitter_mode,
                  transmitter_type,
                  frame_modules,
+                 frame_end_modules,
                  observer,
                  app_source,
                  transmitter):
@@ -25,18 +29,22 @@ class ProgramCmd:
         self.start_date = start_date
         self.end_date = end_date
         self.working_dir = working_dir
-        self.payloads = payloads
+        self.archives = archives
         self.waterfalls = waterfalls
         self.demoddata = demoddata
-        self.payload_modules = payload_modules
+        self.archive_modules = archive_modules
+        self.archive_end_modules = archive_end_modules
         self.demoddata_modules = demoddata_modules
+        self.demoddata_end_modules = demoddata_end_modules
         self.waterfall_modules = waterfall_modules
+        self.waterfall_end_modules = waterfall_end_modules
         self.observation_status = observation_status
         self.user = user
         self.transmitter_uuid = transmitter_uuid
         self.transmitter_mode = transmitter_mode
         self.transmitter_type = transmitter_type
         self.frame_modules = frame_modules
+        self.frame_end_modules = frame_end_modules
         self.observer = observer
         self.app_source = app_source
         self.transmitter = transmitter
