@@ -2,9 +2,10 @@ from glouton.shared.logger import logger
 
 
 class DownloadWorker:
-    def __init__(self, queue, download_status):
+    def __init__(self, queue, download_status, is_download_finished):
         self._commands = queue
         self.__download_status = download_status
+        self.__is_download_finished = is_download_finished
 
     def execute(self):
         self.__download_status.set()
@@ -18,3 +19,5 @@ class DownloadWorker:
             logger.Error(ex)
 
         self.__download_status.clear()
+        if self.__is_download_finished is not None:
+            self.__is_download_finished.set()
